==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/uz-Cyrl-UZ.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0422}\N{U+041e}",
    "\N{U+0422}\N{U+041a}",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E, B h:mm",
    EBhms => "E, B h:mm:ss",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, E",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM, G y",
    GyMMMEd => "E, d-MMM, G y",
    GyMMMd => "d MMM, G y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "LL",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM, W-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    "MMMMW-count-other" => "MMMM, W-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a (v)",
    hmv => "h:mm a (v)",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMMM => "MMM, y",
    yMMMEd => "E, d-MMM, y",
    yMMMM => "MMMM, y",
    yMMMd => "d MMM, y",
    yMd => "dd/MM/y",
    yQQQ => "y, QQQ",
    yQQQQ => "y, QQQQ",
    "yw-count-one" => "Y, w-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    "yw-count-other" => "Y, w-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
  },
  code => "uz-Cyrl-UZ",
  date_format_full => "EEEE, dd MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0434}\N{U+0443}\N{U+0448}",
    "\N{U+0441}\N{U+0435}\N{U+0448}",
    "\N{U+0447}\N{U+043e}\N{U+0440}",
    "\N{U+043f}\N{U+0430}\N{U+0439}",
    "\N{U+0436}\N{U+0443}\N{U+043c}",
    "\N{U+0448}\N{U+0430}\N{U+043d}",
    "\N{U+044f}\N{U+043a}\N{U+0448}",
  ],
  day_format_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+0416}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_format_wide => [
    "\N{U+0434}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0441}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+043f}\N{U+0430}\N{U+0439}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0436}\N{U+0443}\N{U+043c}\N{U+0430}",
    "\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+044f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0434}\N{U+0443}\N{U+0448}",
    "\N{U+0441}\N{U+0435}\N{U+0448}",
    "\N{U+0447}\N{U+043e}\N{U+0440}",
    "\N{U+043f}\N{U+0430}\N{U+0439}",
    "\N{U+0436}\N{U+0443}\N{U+043c}",
    "\N{U+0448}\N{U+0430}\N{U+043d}",
    "\N{U+044f}\N{U+043a}\N{U+0448}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+0416}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_stand_alone_wide => [
    "\N{U+0434}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0441}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+043f}\N{U+0430}\N{U+0439}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0436}\N{U+0443}\N{U+043c}\N{U+0430}",
    "\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+044f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
  ],
  era_abbreviated => [
    "\N{U+043c}.\N{U+0430}.",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  era_narrow => [
    "\N{U+043c}.\N{U+0430}.",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  era_wide => [
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0434}\N{U+0430}\N{U+043d} \N{U+0430}\N{U+0432}\N{U+0432}\N{U+0430}\N{U+043b}\N{U+0433}\N{U+0438}",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%d %B, %Y \N{U+0439}\N{U+0438}\N{U+043b}, %A",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%T, %d %B, %Y \N{U+0439}\N{U+0438}\N{U+043b}, %A",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Uzbek",
  month_format_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043d}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+044f}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043d}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+044f}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  name => "Uzbek Uzbekistan Cyrillic",
  native_language => "\N{U+045e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0447}\N{U+0430}",
  native_name => "\N{U+045e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0447}\N{U+0430} \N{U+040e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+043d} \N{U+041a}\N{U+0438}\N{U+0440}\N{U+0438}\N{U+043b}",
  native_script => "\N{U+041a}\N{U+0438}\N{U+0440}\N{U+0438}\N{U+043b}",
  native_territory => "\N{U+040e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+043d}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+0447}",
    "2-\N{U+0447}",
    "3-\N{U+0447}",
    "4-\N{U+0447}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "2-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "3-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "4-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+0447}",
    "2-\N{U+0447}",
    "3-\N{U+0447}",
    "4-\N{U+0447}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "2-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "3-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "4-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
  ],
  script => "Cyrillic",
  territory => "Uzbekistan",
  time_format_full => "HH:mm:ss (zzzz)",
  time_format_long => "HH:mm:ss (z)",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/uz-Cyrl-UZ.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0422}\N{U+041e}",
    "\N{U+0422}\N{U+041a}",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E, B h:mm",
    EBhms => "E, B h:mm:ss",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, E",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "MMM, G y",
    GyMMMEd => "E, d-MMM, G y",
    GyMMMd => "d MMM, G y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "LL",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM, W-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    "MMMMW-count-other" => "MMMM, W-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a (v)",
    hmv => "h:mm\N{U+202f}a (v)",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMMM => "MMM, y",
    yMMMEd => "E, d-MMM, y",
    yMMMM => "MMMM, y",
    yMMMd => "d MMM, y",
    yMd => "dd/MM/y",
    yQQQ => "y, QQQ",
    yQQQQ => "y, QQQQ",
    "yw-count-one" => "Y, w-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
    "yw-count-other" => "Y, w-'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}'",
  },
  code => "uz-Cyrl-UZ",
  date_format_full => "EEEE, dd MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0434}\N{U+0443}\N{U+0448}",
    "\N{U+0441}\N{U+0435}\N{U+0448}",
    "\N{U+0447}\N{U+043e}\N{U+0440}",
    "\N{U+043f}\N{U+0430}\N{U+0439}",
    "\N{U+0436}\N{U+0443}\N{U+043c}",
    "\N{U+0448}\N{U+0430}\N{U+043d}",
    "\N{U+044f}\N{U+043a}\N{U+0448}",
  ],
  day_format_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+0416}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_format_wide => [
    "\N{U+0434}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0441}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+043f}\N{U+0430}\N{U+0439}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0436}\N{U+0443}\N{U+043c}\N{U+0430}",
    "\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+044f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0434}\N{U+0443}\N{U+0448}",
    "\N{U+0441}\N{U+0435}\N{U+0448}",
    "\N{U+0447}\N{U+043e}\N{U+0440}",
    "\N{U+043f}\N{U+0430}\N{U+0439}",
    "\N{U+0436}\N{U+0443}\N{U+043c}",
    "\N{U+0448}\N{U+0430}\N{U+043d}",
    "\N{U+044f}\N{U+043a}\N{U+0448}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+0416}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_stand_alone_wide => [
    "\N{U+0434}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0441}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+043f}\N{U+0430}\N{U+0439}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+0436}\N{U+0443}\N{U+043c}\N{U+0430}",
    "\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
    "\N{U+044f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0430}",
  ],
  era_abbreviated => [
    "\N{U+043c}.\N{U+0430}.",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  era_narrow => [
    "\N{U+043c}.\N{U+0430}.",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  era_wide => [
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0434}\N{U+0430}\N{U+043d} \N{U+0430}\N{U+0432}\N{U+0432}\N{U+0430}\N{U+043b}\N{U+0433}\N{U+0438}",
    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+0439}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%d %B, %Y \N{U+0439}\N{U+0438}\N{U+043b}, %A",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%T, %d %B, %Y \N{U+0439}\N{U+0438}\N{U+043b}, %A",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Uzbek",
  month_format_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043d}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+044f}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043d}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+044f}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0438}\N{U+044e}\N{U+043d}",
    "\N{U+0438}\N{U+044e}\N{U+043b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  name => "Uzbek Uzbekistan Cyrillic",
  native_language => "\N{U+045e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0447}\N{U+0430}",
  native_name => "\N{U+045e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0447}\N{U+0430} \N{U+040e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+043d} \N{U+041a}\N{U+0438}\N{U+0440}\N{U+0438}\N{U+043b}",
  native_script => "\N{U+041a}\N{U+0438}\N{U+0440}\N{U+0438}\N{U+043b}",
  native_territory => "\N{U+040e}\N{U+0437}\N{U+0431}\N{U+0435}\N{U+043a}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+043d}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+0447}",
    "2-\N{U+0447}",
    "3-\N{U+0447}",
    "4-\N{U+0447}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "2-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "3-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "4-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+0447}",
    "2-\N{U+0447}",
    "3-\N{U+0447}",
    "4-\N{U+0447}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "2-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "3-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "4-\N{U+0447}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
  ],
  script => "Cyrillic",
  territory => "Uzbekistan",
  time_format_full => "HH:mm:ss (zzzz)",
  time_format_long => "HH:mm:ss (z)",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
